@@ -37,7 +37,7 @@ Usage::
     scan_paginator: ScanPaginator = client.get_paginator("scan")
     ```
 """
-from mypy_boto3_dynamodb.client import DynamoDBClient as Client, DynamoDBClient
+from mypy_boto3_dynamodb.client import DynamoDBClient, DynamoDBClient as Client
 from mypy_boto3_dynamodb.paginator import (
     ListBackupsPaginator,
     ListTablesPaginator,
